# django-biblatex

Biblatex app for django.

![Linting & Tests](https://github.com/jnphilipp/django-biblatex/actions/workflows/tests.yml/badge.svg)
[![pypi Version](https://img.shields.io/pypi/v/django-biblatex.svg?logo=pypi&logoColor=white)](https://pypi.org/project/django-biblatex/)

